;|
*******************************************************************
*                                                                 *
* Wir sind das "Express-Tools 2 German Project"                   *
* Nachfolgend nur noch abgekrzt durch "ET2GP" !                  *
* --------------------------------------------------------------- *
* Die Beteiligten in alphabetischer Reihenfolge:                  *
*                                                                 *
* Vorname, Name         E-Mail-Adresse          Website           *
* --------------------------------------------------------------- *
* Holger Brischke       kontakt@defun.de        www.defun.de      *
* Martin Drese          drese@defun.de          keine Website     *
* Markus Hoffmann       hoffmann@defun.de       keine Website     *
* Marc Scherer          marc.scherer@zvo.com    keine Website     *
* Peter Tropf           info@petertropf.de      keine Website     *
*                                                                 *
* Special Guest (bersetzung der Hilfe-Texte)                     *
* Walter Verburg        walterverburg@web.de    keine Website     *
*                                                                 *
*******************************************************************

***ET2GP-Anpassung*** -> Kommentar
Diese bersetzung der Express-Tools fr AutoCAD 2004 basiert auf den
originalen, mit AutoCAD 2004 gelieferten Express-Tools von Autodesk.
Da nicht jeder deutsch-sprachige User von AutoCAD des Englischen
mchtig ist, haben wir diese bersetzung vorgenommen.

nderungen an den Originaltexten sind immer mit einem einleitenden
Kommentar versehen, wobei die Steuerzeichen fr Kommentare je nach
Dateiart variieren:

Eine nderung an einer Lisp-Datei ist folgendermaen markiert:

;;; ***ET2GP-Anpassung*** ...

Bei einem DCL-File dann so:

/// ***ET2GP-Anpassung*** ...

Originalzeilen bleiben soweit wie mglich erhalten, werden jedoch durch
ein "Auskommentieren" deaktiviert.

Anderweitige Modifikationen, wie z.B. komplett neue Zeilen oder permanent 
deaktivierte Funktionen sind mit einem erklrendem Kommentar versehen.

Beispiel:
...
;;; ***ET2GP-Anpassung*** -> Dialog bersetzt...
         ;_ (prompt "\nSelect object(s) on the layer(s) to be isolated: ")
         (prompt "\nObjekt(e) auf zu isolierenden Layern whlen: ")
...

Jede angepasste Datei wird mit diesem Header vorneweg versehen, wobei die
nachfolgenden Zeilen bezglich der Informationen (wie z.B. Name des bersetzers)
natrlich variabel sind.

***ET2GP-Anpassung*** -> Kommentar
Version 1.0
30.09.2003
Holger Brischke
|;
;;
;;  exoffset.lsp - Express Tools offset replacement command
;;                    
;;
;;  Copyright  1999 by Autodesk, Inc.
;;
;;  Your use of this software is governed by the terms and conditions
;;  of the License Agreement you accepted prior to installation of this
;;  software.  Please note that pursuant to the License Agreement for this
;;  software, "[c]opying of this computer program or its documentation
;;  except as permitted by this License is copyright infringement under
;;  the laws of your country.  If you copy this computer program without
;;  permission of Autodesk, you are violating the law."
;;
;;  AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
;;  AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
;;  MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC.
;;  DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
;;  UNINTERRUPTED OR ERROR FREE.
;;
 
;|
 
EXOFFSET
Express offset
 
This command is direct a replacement for offset.
The prompt sequence is the same as the standard offste command 
except that this command has several added options and enhancements.
Enhanced features include:
 
- Option to specify what layer new objects are placed on (Current or Source).
 
- Ability to select mutiple objects to be offset and dynamically step 
  through each one to specify an offset side.
 
- Undo option within the command.
 
- Multiple option allows you to offset a single selected object 
  multiple times without re-selecting it each time.
 
- Ability to set a new offset distance at any point within the command.
 
- Improved selection. Finally offset allows standard options like 
  implied crossing and window as well as fence and others.
 
|;
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun c:exOffset ( / flt na ss exOffset-err undolst )
 (acet-error-init
  (list (list "cmdecho" 0)
        0
        '(exOffset-err)
  )
 )
 
 ;; extra error stuff
 (defun-q exOffset-err ()
  (if (and na 
           (equal 'ENAME (type na))
      );and
      (setq na (ssadd na))
  );if
  (if (and na
           (equal 'PICKSET (type na))
      );and
      (acet-ss-redraw na 4)
  );if
  (if lk
      (progn
       (acet-sysvar-set (list "cmdecho" 0))
       (command "_.-layer" "_lock" lk "")
       (acet-sysvar-restore)
      );progn then
  );if
  (princ)
 );defun-q
 
 (setq flt '((-4 . "<OR") (0 . "LINE") (0 . "CIRCLE") (0 . "ARC") (0 . "POLYLINE")
                          (0 . "LWPOLYLINE") (0 . "ELLIPSE") (0 . "RAY")
                          (0 . "XLINE") (0 . "SPLINE")
             (-4 . "OR>")
            )
 );setq
 
 (if (and (= (getvar "pickfirst"))
          (setq na (cadr (ssgetfirst)))
     );and
     (progn
      ;(setq na (acet-ss-ssget-filter na flt))
 
      (setq ss (car (acet-ss-filter 
                        (list na '(( "LAYERUNLOCKED")) T)
                    )
               );car
      );setq
 
      (sssetfirst nil nil)
     );progn
     (sssetfirst nil nil)
 );if
 
 (acet-exOffset-print-status)
 (acet-exOffset-ui-get-dist)
 (while (or na
            (setq na (acet-ui-entsel
                      (list
                        ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                        ;"\nSelect object(s) to offset or [Options/Undo]: "
                        "\nObjekt(e) fr das Versetzen whlen oder [Optionen/Zurck]: "	;; prompt
                            128							;; bits
                        ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                        ;"Options Undo"
                            "Optionen Zurck"					;; keywords
                            T							;; implied windowing ok
                            flt							;; filter
                            nil							;; lockedOK
                      );list
                     )
            );setq
        );or
   (cond
    ((equal (type na) 'PICKSET)
     (princ (acet-str-format
              ;;; ***ET2GP-Anpassung*** -> Info bersetzt
              ;"\n%1 object(s) found."
              "\n%1 Objekt(e) gefunden."
              (itoa (sslength na))))
     (setq undolst (acet-exOffset-ui-multi-select na undolst))
    );cond #2
    ;; ***ET2GP-Anpassung*** -> Keyword bersetzt
    ;; ((equal na "Options")
    ((equal na "Optionen")
     (acet-exOffset-ui-get-settings)
    );cond #3
    ((equal na "Zurck")
     (setq undolst (acet-exOffset-undo undolst))
    );cond #4
   );cond close
 
   (setq na nil)
 );while
 
 ;; get rid of any duplicates that may have been created
 (acet-exoffset-remove-dups undolst)
 
 (acet-error-restore)
);defun c:exOffset
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Takes an ename or a selection set and erases the obnjkects using entdel so that undo does not 
; get affected.
;
(defun acet-exoffset-erase ( ss / n na )
 (if (equal 'ENAME (type ss))
     (setq ss (ssadd ss (ssadd)))
 );if
 (setq n 0)
 (repeat (sslength ss)
  (setq na (ssname ss n))
  (if (entget na)
      (entdel na)
  );if
  (setq n (+ n 1));setq
 );repeat
);defun acet-exoffset-erase
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exoffset-clean ( lst / n na lst2 lst3 lst4 )
  (setq n 0)
  (repeat (length lst)
   (setq lst2 (nth n lst)
         lst3 nil
   );setq
 
   (foreach na lst2
     (if (entget na)
         (setq lst3 (cons na lst3))
     );if
   );foreach
   (setq lst4 (cons (reverse lst3) lst4))
 
   (setq n (+ n 1));setq
  );repeat
  (setq lst (reverse lst4))
 
);defun acet-exoffset-clean
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Takes a list of lists. Each sub-list is a list of enames.
;
(defun acet-exoffset-remove-dups ( lst / ss lst2 lst3 lst4 n na ss2 )
 
 (if (and lst
          (setq lst2 (acet-exoffset-clean lst))
          (setq lst2 (apply 'append lst2))
          (setq ss (acet-list-to-ss lst2));setq
          (setq ss (acet-ss-remove-dups ss 0.00000001 nil))
          (setq ss2 (cadr ss))
     );and
     (progn
      (setq ss (car ss))
      (if ss2
          (progn
           (if (ssmemb (car (car lst)) ss2)
               (setq ss2 (ssdel (car (car lst)) ss2)
                      ss (ssadd (car (car lst)) ss)
               );setq then
           );if
           (if (> (sslength ss2) 0)
               (progn
                (acet-exoffset-erase ss2)
                (princ (acet-str-format
                         ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                         ;"\nRemoved %1 duplicate object(s)."
                         "\nEntferne %1 doppelte Objekt(e)."
                         (sslength ss2)))
               );progn then
           );if
          );progn then
      );if
;      (setq n 0)
;      (repeat (length lst)
;       (setq lst2 (nth n lst)
;             lst3 nil
;       );setq
; 
;       (foreach na lst2
;         (if (ssmemb na ss)
;             (setq lst3 (cons na lst3))
;         );if
;       );foreach
;       (setq lst4 (cons (reverse lst3) lst4))
;
;       (setq n (+ n 1));setq
;      );repeat
;      (setq lst (reverse lst4))
     );progn then
 );if
 lst
);defun acet-exoffset-remove-dups
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
(defun acet-exOffset-ui-multi-select ( ss undolst / na n j )
 (setq j (sslength ss))
; (if (> j 1)
;     (acet-ui-progress-init "Offset multiple objects..." (sslength ss))
; );if
 
 (setq n 0)
 (repeat (sslength ss)
  (if (> j 1) 
      (progn
       (acet-ui-progress-init
         ;;; ***ET2GP-Anpassung*** -> Info bersetzt
         ;"Offset multiple objects..."
         "Versetze mehrere Objecte..."
         (sslength ss))
       (acet-ui-progress-safe n)
      );progn then
  );if
  (setq na (ssname ss n))
  (setq undolst (acet-exOffset-ui-ent na undolst))
  (setq n (+ n 1));setq
 );repeat
 
 (if (> j 1) (acet-ui-progress-done));if
 
 undolst
);defun acet-exOffset-ui-multi-select
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
(defun acet-exOffset-ui-ent ( na undolst / e1 d p1 mult flag msg shift control )
 
 (acet-sys-shift-down)   ;call once to initialize
 (acet-sys-control-down)
 
 (setq d (acet-exOffset-get-dist))
 (if (= d 0.0)
     (setq d "_through")
 );if
 (while (and 
             (not flag)

             (setq e1 (entget na))
 
             (progn
              (if (acet-layer-locked (cdr (assoc 8 e1)))
                  (progn
                   (princ
                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                     ;"\nObject is on a locked layer."
                     "\nObjekt liegt auf einem gesperrten Layer."
                     )
                   (setq e1 nil)
                  )
              );if
              e1
             );progn
 
;;;;             (not flag)

             (progn
              (redraw na 3)
              (if (and (= 'STR (type d))
                       (acet-str-equal d "_through")
                  );and
                  (setq msg
                         ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                         ;"\nSpecify through point or "
                         "\nDurch Punkt oder "
                        )
                  (setq msg
                         ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                         ;"\nSide to offset or "
                         "\nSeite, auf die versetzt werden soll, oder "
                        )
              );if
              (if (not mult)
                  (progn
                   (princ
                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                     ;"\nShift+Pick for multiple; Ctrl+Pick to erase source object."
;;;                  "\nShift+Wahl fr Hinzufgen; Ctrl+Wahl zum Entfernen Quellobjekt."
;;;                  gendert von Peter Tropf:
                     "\nPicken mit Shift --> Mehrfachmodus; Picken mit Ctrl lscht das Original."
                     )
                   ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                   ;(initget "Multiple Options Undo")
                   (initget "Mehrfach Optionen Zurck _Multiple Options Undo")
                   (setq msg (strcat msg
                                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                                     ;"[Multiple/Options/Undo]: "
                                     "[Mehrfach/Optionen/Zurck]: "
                                     ))
                  );progn then
                  (progn
                   (princ
                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                     ;"\nPress <enter> to exit multiple mode; Ctrl+Pick to erase source object."
;;;                  "\nDrcke <Eingabe> fr Beenden Mehrfachmodus; Ctrl+Wahl zum Entfernen Quellobjekt."
;;;                  gendert von Peter Tropf:
                     "\n<Return> eingeben, um den Mehrfachmodus zu beenden; Picken mit Ctrl lscht das Original."
                     )
                   (initget
                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                     ;"Options Undo"
                     "Options Zurck _Options Undo")
                   (setq msg (strcat msg
                                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                                     ;"[Options/Undo]: "
                                     "[Optionen/Zurck]: "
                                     ))
                  );progn else
              );if
              (setq p1 (getpoint msg))
              (if (equal (type p1) 'LIST)
                  (setq   shift (acet-sys-shift-down)
                        control (acet-sys-control-down)
                  );setq
              );if
              (redraw na 4)
              p1
             );progn
        );and
 
       (cond
        ((equal (type p1) 'LIST)
         (setq undolst (acet-exOffset-ent na d p1 undolst control))
         (if undolst
             (setq na (car (car undolst)));setq then
         );if
         (if (not shift)
             (setq flag T)
         );if
        );cond #1
 
        ((equal p1 "Multiple")
         (setq mult T)
        );cond #2
 
        ((equal p1 "Options")
         (acet-exOffset-ui-get-settings)
         (setq d (acet-exOffset-get-dist))
         (if (= d 0.0)
             (setq d "_through")
         );if
        );cond #3
 
        ((equal p1 "Undo")
         (setq undolst (acet-exOffset-undo undolst))
         (if undolst
             (setq na (car (car undolst)));setq then
         );if
        );cond #4
 
       );cond close
 
       (if mult
           (setq flag nil)
       );if
 
  );while
 
  undolst
);defun acet-exOffset-ui-ent
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
(defun acet-exOffset-undo ( undolst / ss lk )
  (if (not undolst)
      (princ
        ;;; ***ET2GP-Anpassung*** -> Info bersetzt
        ;"\nCommand has been completely undone."
        "\nDer Befehl wurde vollstndig zurck gesetzt."
        )
      (progn
       (setq lk (acet-layer-unlock-all))
       (foreach x (car undolst)
         (entdel x)
       )
       (setq undolst (cdr undolst));setq
       (if lk
           (command "_.layer" "_lock" lk "")
       );if
      );progn then
  );if
 undolst
);defun acet-exOffset-undo
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
(defun acet-exOffset-ent ( na d p1 undolst control / layermode lna ss )
 (setq       lna (entlast)
       layermode (acet-exOffset-get-layermode)
 );setq
 (command "_.offset" d na p1 "")
 (if (not (equal lna (entlast)))
     (progn
      (setq ss (acet-ss-new lna)
            ss (acet-ss-to-list ss)
      );setq
      (if control
          (progn
           (setq ss (append ss (list na)))
           (entdel na)
          );progn then
      );if
      (setq undolst (cons ss undolst));setq
      (if (and (equal layermode "Current")
               (setq ss (acet-list-to-ss ss))
          );and
          (command "_.chprop" ss "" "_la" (getvar "clayer") "")
      );if
      (setq undolst (acet-exoffset-remove-dups undolst))
     );progn then offset succeeded
 );if
 undolst
);defun acet-exOffset-ent
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Offer a main prompt from which the default is the distance entry but other options are included such
; as layer gaptype ....etc.
;
(defun acet-exOffset-ui-get-settings ( / def str ans d )
 (acet-exOffset-print-status)
 (setq def (acet-exOffset-get-dist))
 (if (equal def 0.0)
     (setq str "Through");setq
     (setq str (rtos def))
 );if
 (while (progn
         (initget 6
                  ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                  ;"Distance Layer Gaptype"
                  "Abstand Layer Eckentyp _Distance Layer Gaptype"
                  )
         (setq ans (getkword
                     ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                     ;"\nSpecify an option to set [Distance/Layer/Gaptype]: "
                     "\nOption whlen [Abstand/Layer/Eckentyp]: "
                     ));setq
        );progn 
  (cond
   ((= ans "Distance")
    (acet-exOffset-ui-get-dist)
   );cond #1
   ((equal ans "Layer")
    (acet-exOffset-ui-get-layermode)
   );cond #2
   ((equal ans "Gaptype")
    (acet-exOffset-ui-get-gaptype)
   );cond #3
  );cond close
 );while
);defun acet-exOffset-ui-get-settings
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exOffset-ui-get-dist ( / def str ans d )
 (setq def (acet-exOffset-get-dist))
 (if (equal def 0.0)
     (setq str "Through");setq
     (setq str (rtos def))
 );if
 (while (not d)
  (initget 6 "Durch _Through")
  (setq ANS (getdist ;; ***ET2GP-Anpassung*** -> ET2GP-OPTION-TRANSLATOR eingesetzt
                     (ET2GP-OPTION-TRANSLATOR
                       (acet-str-format
;;; ***ET2GP-Anpassung*** -> Info bersetzt
                                        ;"\nSpecify offset distance or [Through] <%1>: "
                         "\nAbstand oder [Durch] <%1>: "
                         STR
                       ) ;_ end of acet-str-format
                       (list (cons "Through" "Durch"))
                     ) ;_ end of ET2GP-OPTION-TRANSLATOR
            ) ;_ end of getdist
  )                                     ;setq
  (cond
   ((not ans)
    (setq d def)
   );cond #1
   ((= ans "Through")
    (setq d 0.0)
    (acet-setvar (list "ACET-EXOFFSET-DIST" d 3))
   );cond #2
   ((equal 'REAL (type ans))
    (setq d ans)
    (acet-setvar (list "ACET-EXOFFSET-DIST" d 3))
   );cond #3
  );cond close
 );while
 d
);defun acet-exOffset-ui-get-dist
 
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exOffset-get-dist ( / def )
 (setq def (acet-getvar (list "ACET-EXOFFSET-DIST" 3)))
 (if (not def)
     (setq def 0.0)
 );if
 def 
);defun acet-exOffset-get-dist
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exOffset-ui-get-layermode ( / def ans )
 (setq def (acet-exOffset-get-layermode))
 (initget
   ;;; ***ET2GP-Anpassung*** -> Info bersetzt
   ;"Source Current"
   "Original Aktuell _Source Current"
   )
 (setq ANS
        (getkword
          ;; ***ET2GP-Anpassung*** -> ET2GP-OPTION-TRANSLATOR eingesetzt
          (ET2GP-OPTION-TRANSLATOR
            (acet-str-format
;;; ***ET2GP-Anpassung*** -> Info bersetzt
                                        ;"\nSpecify layer for new objects [Source/Current] <%1>: "
              "\nLayer des neuen Objektes [Original/Aktuell] <%1>: "
              DEF
            ) ;_ end of acet-str-format
            (list (cons "Source" "Original") (cons "Current" "Aktuell"))
          ) ;_ end of ET2GP-OPTION-TRANSLATOR
        ) ;_ end of getkword
 ) ;_ end of setq
 (if ans
     (acet-setvar (list "ACET-EXOFFSET-LAYERMODE" ans 3)) ;store it in dwg and current profile
     (setq ans def)
 );if
 ans
);defun acet-exOffset-ui-get-layermode
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exOffset-get-layermode ( / def )
 (setq def (acet-getvar '("ACET-EXOFFSET-LAYERMODE")))
 (if (not def)
     (setq def "Source")
 );if
 def
);defun acet-exOffset-get-layermode
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun acet-exOffset-ui-get-gaptype ( / def ans )
 (setq def (getvar "offsetgaptype"))
 (cond
  ((= def 0) (setq ans "Normal"))
  ((= def 1) (setq ans "Fillet"))
  ((= def 2) (setq ans "Chamfer"))
 );cond close
 (initget
   ;;; ***ET2GP-Anpassung*** -> Info bersetzt
   ;"Normal Fillet Chamfer"
   "Normal Abrunden Fase _Normal Fillet Chamfer"
   )
 (setq ANS
        (getkword
          ;; ***ET2GP-Anpassung*** -> ET2GP-OPTION-TRANSLATOR eingesetzt
          (ET2GP-OPTION-TRANSLATOR
            (acet-str-format
;;; ***ET2GP-Anpassung*** -> Info bersetzt
                                        ;"\nSpecify offset behavior for plines [Normal/Fillet/Chamfer] <%1>: "
              "\nEinstellung fr das Polylinien-Versetzen [Normal/Abrunden/Fase] <%1>: "
              ANS
            ) ;_ end of acet-str-format
            (list (cons "Fillet" "Abrunden") (cons "Chamfer" "Fase"))
          ) ;_ end of ET2GP-OPTION-TRANSLATOR
        ) ;_ end of getkword
 ) ;_ end of setq
 (if ans
     (progn
       (cond
         ((= ANS "Normal") (setq ANS 0))
         ((= ANS "Fillet") (setq ANS 1))
         ((= ANS "Chamfer") (setq ANS 2))
       ) ;_ end of cond
       (setvar "offsetgaptype" ANS)
     )                                  ;progn then
     (setq ans def)
 );if
 ans
);defun acet-exOffset-ui-get-gaptype
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
(defun acet-exOffset-print-status ( / dist lay gap )
 (setq dist (acet-exOffset-get-dist)
        lay (xstrcase (acet-exOffset-get-layermode))
        gap (getvar "offsetgaptype")
 );setq
 (if (= DIST 0)
   (setq DIST "Through")
   (setq DIST (rtos DIST))
 )                                      ;if
 (cond
  ((= gap 0) (setq gap "Normal"))
  ((= gap 1) (setq gap "Fillet"))
  ((= gap 2) (setq gap "Chamfer"))
 );cond close

     
;;; ***ET2GP-Anpassung*** -> Info bersetzt
;;; (princ (acet-str-format "\nSettings: Distance = %1,  Layer = %2, Gaptype = %3"
 (princ
   ;; ***ET2GP-Anpassung*** -> ET2GP-OPTION-TRANSLATOR eingesetzt
   (ET2GP-OPTION-TRANSLATOR ;_ einmal fr Layer
     (ET2GP-OPTION-TRANSLATOR ;_ einmal fr Abstand
       (ET2GP-OPTION-TRANSLATOR ;_ einmal fr Eckentyp
         (acet-str-format
           "\nEinstellungen: Abstand = %1,  Layer = %2, Eckentyp = %3"
           DIST
           LAY
           GAP
         ) ;_ end of acet-str-format
         (list (cons "Fillet" "Abrunden") (cons "Chamfer" "Fase"))
       ) ;_ end of ET2GP-OPTION-TRANSLATOR
       (list (cons "Through" "Durch"))
     ) ;_ end of ET2GP-OPTION-TRANSLATOR
     (list (cons "SOURCE" "ORIGINAL") (cons "CURRENT" "AKTUELL"))
   ) ;_ end of ET2GP-OPTION-TRANSLATOR
 )                                      ;princ
);defun acet-exOffset-print-status


(princ)
